Function _git

pub fn _git<S: AsRef<OsStr> + Debug>(
    working_dir: &Path,
    arguments: &[S],
    quiet: bool,
) -> Result<bool>
Execute the external “git” command with base_path as its current directory and with the given arguments. Returns true when git exited with code 0, false if 1; returns an error for other exit codes or errors.