Struct GitWorkingDir

pub struct GitWorkingDir {
    pub working_dir_path: Arc<PathBuf>,
}

Fields

working_dir_path: Arc<PathBuf>

Implementations

Source

impl GitWorkingDir

pub fn working_dir_path_ref(&self) -> &Path

pub fn working_dir_path_arc(&self) -> Arc<PathBuf>

pub fn git<S: AsRef<OsStr> + Debug>( &self, arguments: &[S], quiet: bool, ) -> Result<bool>

Execute the external “git” command with base_path as its current directory and with the given arguments. Returns true when git exited with code 0, false if 1; returns an error for other exit codes or errors.

pub fn git_stdout<S: AsRef<OsStr> + Debug>( &self, arguments: &[S], ) -> Result<Vec<u8>>

Only succeeds if Git exited with code 0.

pub fn git_stdout_accepting<S: AsRef<OsStr> + Debug>( &self, arguments: &[S], acceptable_status_codes: &[i32], ) -> Result<(bool, Vec<u8>)>

Only succeeds if Git exited with one of the given exit codes, returning truthy, too.

pub fn git_stdout_string_trimmed_accepting<S: AsRef<OsStr> + Debug>( &self, arguments: &[S], acceptable_status_codes: &[i32], ) -> Result<(bool, String)>

Retrieve the output from a Git command as utf-8 decoded string, with leading and trailing whitespace removed.

pub fn git_stdout_string_trimmed<S: AsRef<OsStr> + Debug>( &self, arguments: &[S], ) -> Result<String>

Retrieve the output from a Git command as utf-8 decoded string, with leading and trailing whitespace removed.

pub fn git_stdout_optional_string_trimmed<S: AsRef<OsStr> + Debug>( &self, arguments: &[S], ) -> Result<Option<String>>

Retrieve the output from a Git command as utf-8 decoded string, with leading and trailing whitespace removed; return the empty string as None.

pub fn git_branch_show_current(&self) -> Result<Option<String>>

Get the name of the checked-out branch, if any.

pub fn git_describe<S: AsRef<OsStr> + Debug>( &self, arguments: &[S], ) -> Result<String>

Get the name of the checked-out branch, if any.

pub fn get_head_commit_id(&self) -> Result<String>

pub fn git_ls_files(&self) -> Result<Vec<BaseAndRelPath>>

Source

impl GitWorkingDir

Source

impl GitWorkingDir

pub fn git_log<S: AsRef<OsStr> + Debug>( &self, arguments: &[S], ) -> Result<GitLogIterator<ChildStdout, Child>>

Git log will already receive appropriate formatting options (--raw or --format..), don’t give any!

pub fn git_rev_parse( &self, name: &str, to_commit: bool, ) -> Result<Option<String>>

Resolve the given reference. If to_commit is true, resolves to a commit id. Returns None if the reference doesn’t exist / can’t be resolved (details?). Note that it’s not possible to check commit ids for existence, use git_cat_file with GitCatFileMode::ShowExists instead.

pub fn git_tag( &self, tag_name: &str, revision: Option<&str>, message: &str, sign: bool, local_user: Option<&str>, ) -> Result<bool>

Create an annotated or signed Git tag. Returns whether the tag has been created, false means the tag already exists on the same commit (an error is returned if it exists on another commit). Does not check whether the tag message is the same, though!

pub fn git_remote_get_default_for_branch( &self, branch_name: &str, ) -> Result<Option<String>>

Get the name of the remote for the given branch

pub fn git_push<S: AsRef<OsStr> + Debug>( &self, repository: &str, refspecs: &[S], quiet: bool, ) -> Result<()>

Push the given refspecs (like branch or tag names) to the given repository (like remote name).

Source

impl GitWorkingDir

pub fn git_reset<S: AsRef<OsStr> + Debug>( &self, mode: GitResetMode, options: &[S], refspec: &str, quiet: bool, ) -> Result<()>

Source

impl GitWorkingDir

pub fn git_cat_file(&self, mode: GitCatFileMode, object: &str) -> Result<bool>

pub fn contains_reference(&self, object: &str) -> Result<bool>

Shortcut for git_cat_file(GitCatFileMode::ShowExists, ..) for easy reach